@@ -21,9 +21,9 @@
 #include "tdesvnsettings.h"
 #include "svnactions.h"
 #include "dummydisplay.h"
-#include "targets.hpp"
-#include "url.hpp"
-#include "dirent.hpp"
+#include "targets.h"
+#include "url.h"
+#include "dirent.h"
 #include "sub2qt.h"
 #include "ktranslateurl.h"
 #include "sshagent.h"
